from typing import Callable, Union, cast

import hydra
from hydra.utils import to_absolute_path
from omegaconf import DictConfig, OmegaConf, open_dict
from prelims import StaticSitePostsHandler  # type: ignore
from prelims.processor import Recommender  # type: ignore


@hydra.main(config_path="config", config_name="config")
def main(cfg: DictConfig) -> None:
    for handler in cfg.handlers:
        # Work around for Optional field
        # https://omegaconf.readthedocs.io/en/2.1_branch/usage.html#struct-flag
        with open_dict(handler):
            handler.ignore_files = handler.get("ignore_files", [])
            handler.encoding = handler.get("encoding", "utf-8")
        h = StaticSitePostsHandler(
            to_absolute_path(handler.target_path),
            ignore_files=handler.ignore_files,
            encoding=handler.encoding,
        )
        print(f"target: {to_absolute_path(handler.target_path)}")
        for prc in handler.processors:
            set_processor(h, prc)
        h.execute()


def set_processor(h: StaticSitePostsHandler, cfg: DictConfig) -> None:
    if cfg.type == "recommender":
        set_recommender(h, cfg)
    else:
        raise NotImplementedError("Unknown Processor")


TokenizerCallableType = Callable[[str], list[str]]
TfIdfValueType = Union[int, float, str, TokenizerCallableType]


def set_recommender(h: StaticSitePostsHandler, cfg: DictConfig) -> None:
    tfidf_opts = cast(
        dict[str, TfIdfValueType],
        OmegaConf.to_container(cfg.tfidf_options),
    )
    # Work around for Optional field
    # https://omegaconf.readthedocs.io/en/2.1_branch/usage.html#struct-flag
    with open_dict(cfg):
        cfg.tokenizer = cfg.get("tokenizer", None)
    tokenizer_opt = cfg.tokenizer
    if tokenizer_opt:
        if tokenizer_opt.lang == "ja" and tokenizer_opt.type == "sudachi":
            from .ja.tokenizer import Tokenizer

            tokenizer = Tokenizer(mode=tokenizer_opt.mode, dict=tokenizer_opt.dict)
            tfidf_opts["tokenizer"] = tokenizer.tokenize
        else:
            raise NotImplementedError("Unknown lang/type for tokenizer")

    h.register_processor(Recommender(permalink_base=cfg.permalink_base, **tfidf_opts))


if __name__ == "__main__":
    main()



from typing import Optional

from sudachipy import dictionary, tokenizer  # type: ignore


class Tokenizer:
    def __init__(
        self,
        mode: str = "C",
        dict: str = "core",
        max_df: int = 15,
        min_df: int = 2,
        filter_pos: Optional[list] = None,
    ):
        self.tokenizer_obj = dictionary.Dictionary(dict=dict).create()
        self.max_df = max_df
        self.min_df = min_df
        if filter_pos is None:
            filter_pos = ["名詞", "形容詞"]
        self.filter_pos = filter_pos
        if mode == "A":
            self.mode = tokenizer.Tokenizer.SplitMode.A
        elif mode == "B":
            self.mode = tokenizer.Tokenizer.SplitMode.B
        else:
            self.mode = tokenizer.Tokenizer.SplitMode.C

    def tokenize(self, text: str) -> list[str]:
        return [
            m.surface()
            for m in self.tokenizer_obj.tokenize(text, self.mode)
            if m.part_of_speech()[0] in self.filter_pos
            and self.min_df <= len(m.surface()) <= self.max_df
        ]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['prelims_cli', 'prelims_cli.config', 'prelims_cli.ja']

package_data = \
{'': ['*']}

install_requires = \
['hydra-core>=1.1.1,<2.0.0',
 'numpy>=1.22.1,<2.0.0',
 'prelims>=0.0.5,<0.0.6',
 'scipy>=1.7.3,<2.0.0',
 'taskipy>=1.9.0,<2.0.0']

extras_require = \
{'ja': ['SudachiPy>=0.6.2,<0.7.0', 'SudachiDict-full>=20211220,<20211221']}

entry_points = \
{'console_scripts': ['prelims-cli = prelims_cli.cli:main']}

setup_kwargs = {
    'name': 'prelims-cli',
    'version': '0.0.2',
    'description': 'prelims CLI - Front matter post-processor CLI',
    'long_description': None,
    'author': 'Aki Ariga',
    'author_email': 'chezou@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<3.11',
}


setup(**setup_kwargs)
